@@ -82,6 +82,12 @@ ARTICLE is the article number of the current headline.")
 
 ;;; Interface functions
 
+(eval-when-compile
+  (defmacro nnrss-string-as-multibyte (string)
+    (if (featurep 'xemacs)
+	string
+      `(string-as-multibyte ,string))))
+
 (deffoo nnrss-retrieve-headers (articles &optional group server fetch-old)
   (nnrss-possibly-change-group group server)
   (let (e)
@@ -410,10 +416,6 @@ ARTICLE is the article number of the current headline.")
 
 (defalias 'nnrss-insert 'nnrss-insert-w3)
 
-(if (featurep 'xemacs)
-    (defalias 'nnrss-string-as-multibyte 'identity)
-  (defalias 'nnrss-string-as-multibyte 'string-as-multibyte))
-
 ;;; Snarf functions
 
 (defun nnrss-check-group (group server)
@@ -768,3 +770,4 @@ prefix), return the prefix."
 
 ;;; nnrss.el ends here
 
+;;; arch-tag: 12910c07-0cdf-44fb-8d2c-416ded64c267
